Name:           libuv 
Version:        1.46.0
Release:        1%{?dist}
Summary:        Cross-platform asynchronous I/O

# Code is MIT
# Documentation is CC-BY-4.0
# src/inet.c is ISC
# include/uv/tree.h is BSD-2-Clause
License:        MIT and CC-BY-4.0 and ISC AND BSD-2-Clause
URL:            https://libuv.org
Source0:        https://dist.libuv.org/dist/v%{version}/%{name}-v%{version}.tar.gz
Source1:        https://dist.libuv.org/dist/v%{version}/%{name}-v%{version}.tar.gz.sign
# mkdir temp
# gpg --no-default-keyring --keyring temp/keyring.gpg --keyserver keyserver.ubuntu.com \
#  --recv-keys D77B1E34243FBAF05F8E9CC34F55C8C846AB89B9  \
#  FDF519364458319FA8233DC9410E5553AE9BC059 94AE36675C464D64BAFA68DD7434390BDBE9B9C5 \
#  57353E0DBDAAA7E839B66A1AFF47D5E4AD8B4FDC AEAD0A4B686767751A0E4AEF34A25FB128246514 \
#  CFBB9CA9A5BEAFD70E2B3C5A79A67C55A3679C8B C82FA3AE1CBEDC6BE46B9360C43CEC45C17AB93C \
#  612F0EAD9401622379DF4402F28C3C8DA33C03BE \
#  && gpg --no-default-keyring --keyring temp/keyring.gpg --output temp/keysuv.gpg --export
# cp temp/keysuv.gpg .
Source2:        keysuv.gpg

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gnupg2
# Documentation
BuildRequires:  make
BuildRequires:  python3-sphinx

%description
libuv is a multi-platform support library with a focus on asynchronous I/O.
It was primarily developed for use by Node.js, but it's also used by Luvit,
Julia, uvloop, and others.

%package devel
Summary:        Development files for libuv
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Development headers and configuration files
for libuv, an asynchronous I/O library.

%package static
Summary:        Static library for libuv
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description static
Static library for libuv, an asynchronous I/O library.


%prep
gpgv2 --keyring %{SOURCE2} %{SOURCE1} %{SOURCE0}
%autosetup -n %{name}-v%{version}


%build
%cmake -DBUILD_TESTING=ON
%cmake_build
# Build Documentation
cd docs
make man
cd ..

%install
%cmake_install
# install documentation
mkdir -p  %{buildroot}/%{_mandir}/man1/
install -p -m 644 docs/build/man/libuv.1 %{buildroot}/%{_mandir}/man1/
# Remove packaged license files
rm %{buildroot}/%{_docdir}/libuv/LICENSE
rm %{buildroot}/%{_docdir}/libuv/LICENSE-extra


%check
./%{__cmake_builddir}/uv_run_tests
./%{__cmake_builddir}/uv_run_tests_a

%files
%license LICENSE
%license LICENSE-docs
%license LICENSE-extra
%doc SUPPORTED_PLATFORMS.md
%doc README.md
%doc AUTHORS
%doc ChangeLog
%{_mandir}/man1/libuv.1*
%{_libdir}/libuv.so.1*

%files devel
%{_includedir}/uv.h
%dir %{_includedir}/uv
%{_includedir}/uv/*.h
%{_libdir}/libuv.so
%{_libdir}/pkgconfig/libuv.pc
%dir %{_libdir}/cmake/libuv
%{_libdir}/cmake/libuv/*.cmake

%files static
%{_libdir}/libuv.a
%{_libdir}/pkgconfig/libuv-static.pc

%changelog
* Sun Sep 24 2023 Benson Muite <benson_muite@emailplus.org> - 1.46.0-1
- Initial package
